[interchange-cvs] interchange - jon modified lib/Vend/Payment/AuthorizeNet.pm

interchange-core@icdevgroup.org interchange-core@icdevgroup.org
Wed May 21 16:23:01 2003


User:      jon
Date:      2003-05-21 20:22:16 GMT
Modified:  lib/Vend/Payment AuthorizeNet.pm
Log:
Send to Authorize.Net customer shipping address information and company
where available.

Update copyright and icdevgroup information.

Revision  Changes    Path
2.8       +51 -46    interchange/lib/Vend/Payment/AuthorizeNet.pm


rev 2.8, prev_rev 2.7
Index: AuthorizeNet.pm
===================================================================
RCS file: /var/cvs/interchange/lib/Vend/Payment/AuthorizeNet.pm,v
retrieving revision 2.7
retrieving revision 2.8
diff -u -u -r2.7 -r2.8
--- AuthorizeNet.pm	17 Dec 2002 02:39:04 -0000	2.7
+++ AuthorizeNet.pm	21 May 2003 20:22:15 -0000	2.8
@@ -1,18 +1,21 @@
 # Vend::Payment::AuthorizeNet - Interchange AuthorizeNet support
 #
-# $Id: AuthorizeNet.pm,v 2.7 2002/12/17 02:39:04 kwalsh Exp $
+# Connection routine for AuthorizeNet version 3 using the 'ADC Direct Response'
+# method.
 #
-# Copyright (C) 1999-2002 Red Hat, Inc. <interchange@redhat.com>
+# $Id: AuthorizeNet.pm,v 2.8 2003/05/21 20:22:15 jon Exp $
 #
-# by mark@summersault.com with code reused and inspired by
-#	Mike Heins <mheins@redhat.com>
-#	webmaster@nameastar.net
-#   Jeff Nappi <brage@cyberhighway.net>
-#   Paul Delys <paul@gi.alaska.edu>
-#  Edited by Ray Desjardins <ray@dfwmicrotech.com>
-
-# Patches for AUTH_CAPTURE and VOID support contributed by
-# nferrari@ccsc.com (Nelson H Ferrari)
+# Copyright (C) 2003 Interchange Development Group, http://www.icdevgroup.org/
+# Copyright (C) 1999-2002 Red Hat, Inc.
+#
+# Authors:
+# mark@summersault.com
+# Mike Heins <mike@perusion.com>
+# Jeff Nappi <brage@cyberhighway.net>
+# Paul Delys <paul@gi.alaska.edu>
+# webmaster@nameastar.net
+# Ray Desjardins <ray@dfwmicrotech.com>
+# Nelson H Ferrari <nferrari@ccsc.com>
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,16 +32,11 @@
 # Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 # MA  02111-1307  USA.
 
-# Connection routine for AuthorizeNet version 3 using the 'ADC Direct Response'
-# method.
-
-# Reworked extensively to support new Interchange payment stuff by Mike Heins
-
 package Vend::Payment::AuthorizeNet;
 
 =head1 Interchange AuthorizeNet Support
 
-Vend::Payment::AuthorizeNet $Revision: 2.7 $
+Vend::Payment::AuthorizeNet $Revision: 2.8 $
 
 =head1 SYNOPSIS
 
@@ -209,8 +207,8 @@
 
 =item *
 
-If all else fails, Red Hat and other consultants are available to help
-with integration for a fee.
+If all else fails, consultants are available to help with integration for a fee.
+See http://www.icdevgroup.org/ for mailing lists and other information.
 
 =back
 
@@ -221,8 +219,8 @@
 
 =head1 AUTHORS
 
-Mark Stosberg <mark@summersault.com>, based on original code by Mike Heins
-<mheins@redhat.com>.
+Mark Stosberg <mark@summersault.com>.
+Based on original code by Mike Heins <mike@perusion.com>.
 
 =head1 CREDITS
 
@@ -377,31 +375,38 @@
 
 #::logDebug("auth_code=$actual->{auth_code} order_id=$opt->{order_id}");
     my %query = (
-                    x_Test_Request	=> $opt->{test} || charge_param('test'),
-                    x_Card_Num		=> $actual->{mv_credit_card_number},
-                    x_First_Name    => $actual->{b_fname},
-                    x_Last_Name     => $actual->{b_lname},
-                    x_Address       => $actual->{b_address},
-                    x_City          => $actual->{b_city},
-                    x_State         => $actual->{b_state},
-                    x_Zip			=> $actual->{b_zip},
-                    x_Country		=> $actual->{b_country},
-					x_Type			=> $transtype,
-                    x_Amount    	=> $amount,
-                    x_Exp_Date  	=> $exp,
-                    x_Method    	=> 'CC',
-					x_Trans_ID		=> $actual->{order_id},
-					x_Auth_Code		=> $actual->{auth_code},
-                    x_Invoice_Num   => $actual->{mv_order_number},
-#                    x_Company      => $actual->{company},
-                    x_Email         => $actual->{email},
-                    x_Phone        => $actual->{phone_day},
-                    x_Password  	=> $secret,
-                    x_Login     	=> $user,
-                    x_Version   	=> '3.0',
-                    x_ADC_URL   	=> 'FALSE',
-                    x_ADC_Delim_Data	=> 'TRUE',
-
+		x_Test_Request			=> $opt->{test} || charge_param('test'),
+		x_First_Name			=> $actual->{b_fname},
+		x_Last_Name				=> $actual->{b_lname},
+		x_Company				=> $actual->{b_company},
+		x_Address				=> $actual->{b_address},
+		x_City					=> $actual->{b_city},
+		x_State					=> $actual->{b_state},
+		x_Zip					=> $actual->{b_zip},
+		x_Country				=> $actual->{b_country},
+		x_Ship_To_First_Name	=> $actual->{fname},
+		x_Ship_To_Last_Name		=> $actual->{lname},
+		x_Ship_To_Company		=> $actual->{company},
+		x_Ship_To_Address		=> $actual->{address},
+		x_Ship_To_City			=> $actual->{city},
+		x_Ship_To_State			=> $actual->{state},
+		x_Ship_To_Zip			=> $actual->{zip},
+		x_Ship_To_Country		=> $actual->{country},
+		x_Email					=> $actual->{email},
+		x_Phone					=> $actual->{phone_day},
+		x_Type					=> $transtype,
+		x_Amount				=> $amount,
+		x_Method				=> 'CC',
+		x_Card_Num				=> $actual->{mv_credit_card_number},
+		x_Exp_Date				=> $exp,
+		x_Trans_ID				=> $actual->{order_id},
+		x_Auth_Code				=> $actual->{auth_code},
+		x_Invoice_Num			=> $actual->{mv_order_number},
+		x_Password				=> $secret,
+		x_Login					=> $user,
+		x_Version				=> '3.0',
+		x_ADC_URL				=> 'FALSE',
+		x_ADC_Delim_Data		=> 'TRUE',
     );
 
     my @query;